@@ -14,7 +14,7 @@ from threading import Thread
 from pathlib import Path
 
 from mitosheet.api.get_column_dtype import get_column_dtype
-from mitosheet.api.get_column_summary_graph import get_column_summary_graph
+from mitosheet.api.get_graph import get_graph
 from mitosheet.api.get_saved_analysis_description import get_saved_analysis_description
 from mitosheet.api.get_column_describe import get_column_describe
 from mitosheet.steps.import_steps.raw_python_import import RAW_PYTHON_IMPORT_STEP_TYPE
@@ -34,7 +34,7 @@ class API():
         Stops a backlog of calls from building up.
     -   All API calls should only be reads. This stops us from having to worry 
         about most concurrency issues
-    -   Note that printing inside of a thread does not work properly! 
+    -   Note that printing inside of a thread does not work properly! Use sys.stdout.flush() after the print statement.
         See here: https://stackoverflow.com/questions/18234469/python-multithreaded-print-statements-delayed-until-all-threads-complete-executi
     """
     def __init__(self, wsc, send):
@@ -166,6 +166,7 @@ def handle_api_event(send, event, wsc):
     API must return the same ID that the incoming message contains,
     so that the frontend knows how to match the responses.
     """    
+
     # And then handle it
     if event['type'] == 'datafiles':
         handle_datafiles(send, event)
@@ -173,8 +174,8 @@ def handle_api_event(send, event, wsc):
         handle_import_summary(send, event)
     elif event['type'] == 'get_dataframe_as_csv':
         get_dataframe_as_csv(send, event, wsc)
-    elif event['type'] == 'get_column_summary_graph':
-        get_column_summary_graph(send, event, wsc)
+    elif event['type'] == 'get_graph':
+        get_graph(send, event, wsc)
     elif event['type'] == 'get_column_describe':
         get_column_describe(send, event, wsc)
     elif event['type'] == 'get_column_dtype':
