@@ -404,4 +404,5 @@ def get_recent_traceback_as_list():
     We get this as a list of strings, as mixpanel truncates strings at 255 chars
     and thus we avoid things getting chopped this way.
     """
-    return traceback.format_exc().split('\n')
+    # NOTE: We ignore empty lines, as they add no information
+    return [line for line in traceback.format_exc().split('\n') if line != '']
